@@ -1691,28 +1691,17 @@ namespace netgen
 	coord[i] = dir * Vec<3> (apoints[i]);
       
       QuickSort (coord, apoints);
-      
-      /*
-	for (int i = 0; i < apoints.Size(); i++)
-	for (int j = 0; j < apoints.Size()-1; j++)
-	if ( (dir * Vec<3> (apoints[j])) > (dir * Vec<3> (apoints[j+1])))
-	swap (apoints[j], apoints[j+1]);
-      */
     }
 
 
 
 
 
-
-
     Box<3> bbox (apoints[0], apoints[0]);
     for (int i = 1; i < apoints.Size(); i++)
       bbox.Add (apoints[i]);
     bbox.Increase (0.1 * bbox.Diam());
 
-    //testout->precision(20);
-    (*testout) << "bbox = " << bbox << endl;
     (*testout) << "points = " << apoints << endl;
 
     Point3dTree searchtree (bbox.PMin(), bbox.PMax());
