@@ -15,39 +15,48 @@ namespace netgen
 #include "writeuser.hpp"
 
 
-void RegisterUserFormats (ARRAY<const char*> & names)
+  void RegisterUserFormats (Array<const char*> & names,
+			    Array<const char*> & extensions)
+			    
 {
-  char *types[] =
+  const char *types[] =
     {
-      "Neutral Format",
-      "Surface Mesh Format" ,
-      "DIFFPACK Format",
-      "TecPlot Format",     
-      "Tochnog Format",
-      "Abaqus Format",
-      "Fluent Format",
-      "Permas Format",
-      "FEAP Format",
-      "Elmer Format",
-      "STL Format",
-      "VRML Format",
-      "Gmsh Format",
+      "Neutral Format",  ".mesh",
+      "Surface Mesh Format", ".mesh" ,
+      "DIFFPACK Format", ".mesh",
+      "TecPlot Format", ".mesh",
+      "Tochnog Format", ".mesh",
+      "Abaqus Format", ".mesh",
+      "Fluent Format", ".mesh",
+      "Permas Format", ".mesh",
+      "FEAP Format", ".mesh",
+      "Elmer Format", "*",
+      "STL Format", ".stl",
+      "VRML Format", ".*",
+      "Gmsh Format", ".gmsh",
+      "Gmsh2 Format", ".gmsh2",
+      "OpenFOAM 1.5+ Format", "*",
+      "JCMwave Format", ".jcm",
+      "TET Format", ".tet",
       //      { "Chemnitz Format" },
       0
     };
-
-  for (int i = 0; types[i]; i++)
-    names.Append (types[i]);
+  
+  for (int i = 0; types[2*i]; i++)
+    {
+      names.Append (types[2*i]);
+      extensions.Append (types[2*i+1]);
+    }
 }
+  
 
 
-
-bool WriteUserFormat (const string & format, 	
+bool WriteUserFormat (const string & format,
 		      const Mesh & mesh,
 		      const CSGeometry & geom,
 		      const string & filename)
 {
-  PrintMessage (1, "Export mesh to file ", filename, 
+  PrintMessage (1, "Export mesh to file ", filename,
 		", format is ", format);
 
   if (format == "Neutral Format")
@@ -98,8 +107,26 @@ bool WriteUserFormat (const string & format,
 
   else if (format == "Gmsh Format")
     WriteGmshFormat (mesh, geom, filename);
- 
-  else 
+
+  // Philippose - 29/01/2009
+  // Added Gmsh v2.xx Mesh export capability
+  else if (format == "Gmsh2 Format")
+    WriteGmsh2Format (mesh, geom, filename);
+
+  // Philippose - 25/10/2009
+  // Added OpenFOAM 1.5+ Mesh export capability
+  else if (format == "OpenFOAM 1.5+ Format")
+    WriteOpenFOAM15xFormat (mesh, filename);
+
+  else if (format == "JCMwave Format")
+    WriteJCMFormat (mesh, geom, filename);
+
+#ifdef OLIVER
+  else if (format == "TET Format")
+    WriteTETFormat( mesh, filename);//, "High Frequency" );
+#endif
+
+  else
     {
       return 1;
     }
@@ -125,7 +152,7 @@ void WriteNeutralFormat (const Mesh & mesh,
   int nse = mesh.GetNSE();
   int nseg = mesh.GetNSeg();
   int i, j;
-  
+
   int inverttets = mparam.inverttets;
   int invertsurf = mparam.inverttrigs;
 
@@ -134,13 +161,13 @@ void WriteNeutralFormat (const Mesh & mesh,
   outfile.precision(6);
   outfile.setf (ios::fixed, ios::floatfield);
   outfile.setf (ios::showpoint);
-  
+
   outfile << np << "\n";
-  
+
   for (i = 1; i <= np; i++)
     {
       const Point3d & p = mesh.Point(i);
-      
+
       outfile.width(10);
       outfile << p.X() << " ";
       outfile.width(9);
@@ -202,10 +229,10 @@ void WriteNeutralFormat (const Mesh & mesh,
 
 	  outfile << " ";
 	  outfile.width(8);
-	  outfile << seg.p1;
+	  outfile << seg[0];
 	  outfile << " ";
 	  outfile.width(8);
-	  outfile << seg.p2;
+	  outfile << seg[1];
 
 	  outfile << "\n";
 	}
@@ -225,20 +252,20 @@ void WriteSurfaceFormat (const Mesh & mesh,
 {
   // surface mesh
   int i, j;
-  
+
   cout << "Write Surface Mesh" << endl;
-  
+
   ofstream outfile (filename.c_str());
-  
+
   outfile << "surfacemesh" << endl;
-  
+
   outfile << mesh.GetNP() << endl;
   for (i = 1; i <= mesh.GetNP(); i++)
     {
-      for (j = 1; j <= 3; j++)
+      for (j = 0; j < 3; j++)
 	{
 	  outfile.width(10);
-	  outfile << mesh.Point(i).X(j) << " ";
+	  outfile << mesh.Point(i)(j) << " ";
 	}
       outfile << endl;
     }
@@ -266,37 +293,37 @@ void WriteSTLFormat (const Mesh & mesh,
 		     const string & filename)
 {
   cout << "\nWrite STL Surface Mesh" << endl;
-  
+
   ofstream outfile (filename.c_str());
-  
-  int i, j, k;
-  
+
+  int i;
+
   outfile.precision(10);
-  
+
   outfile << "solid" << endl;
-  
+
   for (i = 1; i <= mesh.GetNSE(); i++)
     {
       outfile << "facet normal ";
       const Point3d& p1 = mesh.Point(mesh.SurfaceElement(i).PNum(1));
       const Point3d& p2 = mesh.Point(mesh.SurfaceElement(i).PNum(2));
       const Point3d& p3 = mesh.Point(mesh.SurfaceElement(i).PNum(3));
-      
+
       Vec3d normal = Cross(p2-p1,p3-p1);
       if (normal.Length() != 0)
 	{
-	  normal /= (normal.Length());		  
+	  normal /= (normal.Length());
 	}
-      
+
       outfile << normal.X() << " " << normal.Y() << " " << normal.Z() << "\n";
       outfile << "outer loop\n";
-      
+
       outfile << "vertex " << p1.X() << " " << p1.Y() << " " << p1.Z() << "\n";
       outfile << "vertex " << p2.X() << " " << p2.Y() << " " << p2.Z() << "\n";
       outfile << "vertex " << p3.X() << " " << p3.Y() << " " << p3.Z() << "\n";
-      
+
       outfile << "endloop\n";
-      outfile << "endfacet\n"; 
+      outfile << "endfacet\n";
     }
   outfile << "endsolid" << endl;
 }
@@ -319,12 +346,12 @@ void WriteVRMLFormat (const Mesh & mesh,
   if (faces)
 
     {
-      // Output in VRML, IndexedFaceSet is used 
+      // Output in VRML, IndexedFaceSet is used
       // Bartosz Sawicki <sawickib@ee.pw.edu.pl>
 
       int np = mesh.GetNP();
       int nse = mesh.GetNSE();
-      int i, j, k, l;
+      int i, j;
 
       ofstream outfile (filename.c_str());
 
@@ -341,8 +368,8 @@ void WriteVRMLFormat (const Mesh & mesh,
 		 "Shape{ \n"
 		 "appearance Appearance { material Material { }} \n"
                  "geometry IndexedFaceSet { \n"
-                 "coord Coordinate { point [ \n";  
-	        
+                 "coord Coordinate { point [ \n";
+
 
       for (i = 1; i <= np; i++)
         {
@@ -354,12 +381,12 @@ void WriteVRMLFormat (const Mesh & mesh,
 	}
 
       outfile << "  ] } \n"
-                 "coordIndex [ \n";               
-	
+                 "coordIndex [ \n";
+
       for (i = 1; i <= nse; i++)
 	{
 	  const Element2d & el = mesh.SurfaceElement(i);
-      
+
 	  for (j = 1; j <= 3; j++)
 	    {
 	      outfile.width(8);
@@ -367,19 +394,19 @@ void WriteVRMLFormat (const Mesh & mesh,
 	    }
 	  outfile << " -1 \n";
 	}
-      
+
       outfile << "  ] \n";
 
       //define number and RGB definitions of colors
       outfile << "color Color { color [1 0 0, 0 1 0, 0 0 1, 1 1 0]} \n"
                  "colorIndex [\n";
-      
+
       for (i = 1; i <= nse; i++)
 	{
-	  outfile << mesh.GetFaceDescriptor(mesh.SurfaceElement(i).GetIndex ()).BCProperty();      
+	  outfile << mesh.GetFaceDescriptor(mesh.SurfaceElement(i).GetIndex ()).BCProperty();
           outfile << endl;
 	}
-      
+
       outfile << " ] \n"
                  "colorPerVertex FALSE \n"
                  "creaseAngle 0 \n"
@@ -388,7 +415,7 @@ void WriteVRMLFormat (const Mesh & mesh,
 		 "convex TRUE \n"
                  "} } # end of Shape\n"
 		 "] }\n";
-                         
+
     } /* end of VRMLFACES */
 
 
@@ -400,7 +427,7 @@ void WriteVRMLFormat (const Mesh & mesh,
 
       int np = mesh.GetNP();
       int nse = mesh.GetNSE();
-      int i, j, k, l;
+      int i, j;
 
       ofstream outfile (filename.c_str());
 
@@ -417,8 +444,8 @@ void WriteVRMLFormat (const Mesh & mesh,
 	         "Shape{ \n"
 		 "appearance Appearance { material Material { }} \n"
                  "geometry IndexedLineSet { \n"
-                 "coord Coordinate { point [ \n";  
-	        
+                 "coord Coordinate { point [ \n";
+
 
       for (i = 1; i <= np; i++)
         {
@@ -430,40 +457,40 @@ void WriteVRMLFormat (const Mesh & mesh,
 	}
 
       outfile << "  ] } \n"
-                 "coordIndex [ \n";               
-	
+                 "coordIndex [ \n";
+
       for (i = 1; i <= nse; i++)
 	{
 	  const Element2d & el = mesh.SurfaceElement(i);
-      
+
 	  for (j = 1; j <= 3; j++)
 	    {
 	      outfile.width(8);
 	      outfile << el.PNum(j)-1;
 	    }
-	  outfile.width(8);  
-	  outfile << el.PNum(1)-1; 
+	  outfile.width(8);
+	  outfile << el.PNum(1)-1;
 	  outfile << " -1 \n";
 	}
-      
+
       outfile << "  ] \n";
 
-/* Uncomment if you want color mesh    
+/* Uncomment if you want color mesh
       outfile << "color Color { color [1 1 1, 0 1 0, 0 0 1, 1 1 0]} \n"
                  "colorIndex [\n";
-      
+
       for (i = 1; i <= nse; i++)
 	{
-	  outfile << mesh.GetFaceDescriptor(mesh.SurfaceElement(i).GetIndex ()).BCProperty();      
+	  outfile << mesh.GetFaceDescriptor(mesh.SurfaceElement(i).GetIndex ()).BCProperty();
           outfile << endl;
 	}
-      
+
       outfile << " ] \n"
-*/ 
+*/
       outfile << "colorPerVertex FALSE \n"
                  "} } #end of Shape\n"
 		 "] } \n";
-                         
+
     }
 
 }
@@ -480,7 +507,7 @@ void WriteFEPPFormat (const Mesh & mesh,
 		      const CSGeometry & geom,
 		      const string & filename)
 {
-  
+
   ofstream outfile (filename.c_str());
 
   if (mesh.GetDimension() == 3)
@@ -488,7 +515,7 @@ void WriteFEPPFormat (const Mesh & mesh,
     {
 
       // output for FEPP
-      
+
       int np = mesh.GetNP();
       int ne = mesh.GetNE();
       int nse = mesh.GetNSE();
@@ -498,7 +525,7 @@ void WriteFEPPFormat (const Mesh & mesh,
       outfile.precision(5);
       outfile.setf (ios::fixed, ios::floatfield);
       outfile.setf (ios::showpoint);
-      
+
       outfile << "volumemesh4" << endl;
       outfile << nse << endl;
       for (i = 1; i <= nse; i++)
@@ -551,7 +578,7 @@ void WriteFEPPFormat (const Mesh & mesh,
 	  outfile << p.Z() << "\n";
 	}
 
-      /*      
+      /*
       if (typ == WRITE_FEPPML)
 	{
 	  int nbn =  mesh.mlbetweennodes.Size();
@@ -559,7 +586,7 @@ void WriteFEPPFormat (const Mesh & mesh,
 	  for (i = 1; i <= nbn; i++)
 	    outfile << mesh.mlbetweennodes.Get(i).I1() << " "
 		    << mesh.mlbetweennodes.Get(i).I2() << "\n";
-	  
+
 
 	  //	  int ncon = mesh.connectedtonode.Size();
 	  //	  outfile << ncon << "\n";
@@ -576,15 +603,15 @@ void WriteFEPPFormat (const Mesh & mesh,
 	  for (i = 1; i <= ns; i++)
 	    geom.GetSurface(mesh.GetFaceDescriptor(i).SurfNr())->Print(outfile);
 	}
-      else 
+      else
 	outfile << "0" << endl;
     }
 
-  
+
   else
-    
+
     { // 2D fepp format
-      
+
       ;
       /*
       extern SplineGeometry2d * geometry2d;
@@ -618,10 +645,10 @@ void WriteEdgeElementFormat (const Mesh & mesh,
   int nsurfelem = mesh.GetNSE();
   int nedges = top->GetNEdges();
   int i, j;
-  
+
   int inverttets = mparam.inverttets;
   int invertsurf = mparam.inverttrigs;
-  ARRAY<int> edges;
+  Array<int> edges;
 
   ofstream outfile (filename.c_str());
 
@@ -630,12 +657,12 @@ void WriteEdgeElementFormat (const Mesh & mesh,
   outfile.setf (ios::showpoint);
 
 
-  // vertices with coordinates  
+  // vertices with coordinates
   outfile << npoints << "\n";
   for (i = 1; i <= npoints; i++)
     {
       const Point3d & p = mesh.Point(i);
-      
+
       outfile.width(10);
       outfile << p.X() << " ";
       outfile.width(9);
@@ -751,7 +778,7 @@ void WriteFile (int typ,
 		double h)
 {
 
-  
+
   int inverttets = mparam.inverttets;
   int invertsurf = mparam.inverttrigs;
 
@@ -778,11 +805,11 @@ void WriteFile (int typ,
       INDEX_2_HASHTABLE<int> edgeht(mesh.GetNP());
 
       // list of edges
-      ARRAY<INDEX_2> edgelist;
+      Array<INDEX_2> edgelist;
 
       // edge (point) on boundary ?
       BitArray bedge, bpoint(mesh.GetNP());
-      
+
       static int eledges[6][2] = { { 1, 2 } , { 1, 3 } , { 1, 4 },
 				   { 2, 3 } , { 2, 4 } , { 3, 4 } };
 
@@ -805,7 +832,7 @@ void WriteFile (int typ,
 	    }
 	}
 
-      
+
       // set bedges, bpoints
       bedge.SetSize (edgelist.Size());
       bedge.Clear();
@@ -834,7 +861,7 @@ void WriteFile (int typ,
       for (i = 1; i <= mesh.GetNE(); i++)
 	{
 	  const Element & el = mesh.VolumeElement(i);
-	  
+
 	  outfile.width(8);
 	  outfile << i;
 	  for (j = 1; j <= 4; j++)
@@ -868,7 +895,7 @@ void WriteFile (int typ,
       for (i = 1; i <= mesh.GetNP(); i++)
 	{
 	  const Point3d & p = mesh.Point(i);
-	  
+
 	  for (j = 1; j <= 3; j++)
 	    {
 	      outfile.width(8);
@@ -897,3 +924,4 @@ void WriteFile (int typ,
 }
 #endif
 }
+
