@@ -1,14 +1,20 @@
 #ifndef FILE_MESHING
 #define FILE_MESHING
 
-#include <myadt.hpp>
-#include <gprim.hpp>
-#include <linalg.hpp>
-#include <opti.hpp>
+
+
+#include "../include/myadt.hpp"
+#include "../include/gprim.hpp"
+#include "../include/linalg.hpp"
+#include "../include/opti.hpp"
+
+
 
 namespace netgen
 {
 
+  extern int printmessage_importance;
+
   class CSGeometry;
   
   
@@ -43,6 +49,7 @@ namespace netgen
 #include "improve3.hpp"
 #endif
 #include "findip.hpp"
+#include "findip2.hpp"
 
 #include "topology.hpp"
 #include "curvedelems.hpp"
@@ -55,6 +62,18 @@ namespace netgen
 #include "hprefinement.hpp"
 #include "boundarylayer.hpp"
 #include "specials.hpp"
+
+#include "validate.hpp"
+
+#ifdef PARALLEL
+#include "paralleltop.hpp"
+// #include "../parallel/parallelmesh.hpp"
+#endif
+
+#include "basegeom.hpp"
+
+
+
 }
 
 #endif
