@@ -27,7 +27,7 @@ menu .ngmenu.file
 .ngmenu.file add command -label "Load Geometry..." -accelerator "<l><g>" \
     -command { 
 	set types {
-	    {"All Geometry types"   { .stl .stlb .step .stp .geo .in2d .igs .iges .brep .in2dnew .sat} }
+	    {"All Geometry types"   { .stl .stlb .step .stp .geo .in2d .igs .iges .brep .sat} }
 	    {"IGES Geometry"	{.igs .iges} }
 	    {"BREP OpenCascade Geometry"    {.brep} }
 	    {"STL Geometry"        {.stl} }
@@ -35,7 +35,6 @@ menu .ngmenu.file
 	    {"STEP Geometry"    {.step .stp} }
 	    {"Geometry file"       {.geo} }
 	    {"2D Geometry"   {.in2d } } 
-	    {"2D Geometry New"   {.in2dnew } } 
 	} 
 
 	set ACISavailable [Ng_ACISCommand isACISavailable]
@@ -43,13 +42,12 @@ menu .ngmenu.file
 	    lappend types {"ACIS Geometry" {.sat} }
 	}
 
-#	    {"All Geometry types"  {.stl .stlb .step .stp .geo .in2d .igs .iges .brep .in2dnew} }
 	
-#		{"Naomi Geometry"      {.nao} }
-#		{"New Geometry file"   {.ngg} } 
-
-#	set file [tk_getOpenFile -filetypes $types -initialdir $dirname -typevariable loadgeomtypevar]
-	set file [tk_getOpenFile -filetypes $types -initialdir $dirname]
+	if {[catch {
+	    set file [tk_getOpenFile -filetypes $types -initialdir $dirname -typevariable loadgeomtypevar]
+	}]} {
+	    set file [tk_getOpenFile -filetypes $types -initialdir $dirname]
+	}
 	if {$file != ""} {
 	    AddRecentFile $file
 	    Ng_LoadGeometry $file 
@@ -395,10 +393,10 @@ set videoactive 0
 
 
 ## herbert tcl load menue
-.ngmenu.file add command -label "Run tests ..." \
-    -command { runtestdialog }
+# .ngmenu.file add command -label "Run tests ..." \
+\#    -command { runtestdialog }
 ##
-.ngmenu.file add separator
+# .ngmenu.file add separator
 
 .ngmenu.file add command -label "Quit" -accelerator "<q>" \
     -command { puts "Thank you for using $progname"; Ng_Exit; destroy . }
@@ -841,7 +839,7 @@ menu .ngmenu.help
 
 .ngmenu.help add command -label "About..." \
     -command {
-tk_messageBox -message "This is NETGEN \nmainly written by \nJoachim Schöberl \nthanks to \nRobert Gaisbauer, Johannes Gerstmayr, Philippose Rajan"
+tk_messageBox -message "This is NETGEN \nmainly written by \nJoachim Schoeberl \nthanks to \nRobert Gaisbauer, Johannes Gerstmayr, Philippose Rajan"
 }
 
 # tk_menuBar .mbar .mbar.file .mbar.mesh .mbar.test .mbar.help
